Struct registerCall
pub struct registerCall {
pub _0: Address,
pub _1: Vec<Address>,
pub _2: FixedBytes<32>,
pub _3: String,
}Expand description
Function with signature register(address,address[],bytes32,string) and selector 0xad527a59.
function register(address, address[] memory, bytes32, string memory) external;Fields
_0: Address_1: Vec<Address>_2: FixedBytes<32>_3: StringTrait Implementations
impl Clone for registerCall
impl Clone for registerCall
fn clone(&self) -> registerCall
fn clone(&self) -> registerCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl SolCall for registerCall
impl SolCall for registerCall
const SIGNATURE: &'static str = "register(address,address[],bytes32,string)"
const SIGNATURE: &'static str = "register(address,address[],bytes32,string)"
The function’s ABI signature.
type Parameters<'a> = (Address, Array<Address>, FixedBytes<32>, String)
type Parameters<'a> = (Address, Array<Address>, FixedBytes<32>, String)
The underlying tuple type which represents this type’s arguments. Read more
type Token<'a> = <<registerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<registerCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
type Return = registerReturn
type Return = registerReturn
The function’s return struct.
type ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
type ReturnToken<'a> = <<registerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<registerCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.