Struct __lyquor_switch_contractCall
pub struct __lyquor_switch_contractCall(pub Address);Expand description
Function with signature __lyquor_switch_contract(address) and selector 0x28d7d027.
function __lyquor_switch_contract(address) external returns (uint256);Tuple Fields
0: AddressTrait Implementations
impl Clone for __lyquor_switch_contractCall
impl Clone for __lyquor_switch_contractCall
fn clone(&self) -> __lyquor_switch_contractCall
fn clone(&self) -> __lyquor_switch_contractCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl SolCall for __lyquor_switch_contractCall
impl SolCall for __lyquor_switch_contractCall
type Parameters<'a> = (Address,)
type Parameters<'a> = (Address,)
The underlying tuple type which represents this type’s arguments. Read more
type Token<'a> = <<__lyquor_switch_contractCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<__lyquor_switch_contractCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
type ReturnTuple<'a> = (Uint<256>,)
type ReturnTuple<'a> = (Uint<256>,)
The underlying tuple type which represents this type’s return values. Read more
type ReturnToken<'a> = <<__lyquor_switch_contractCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<__lyquor_switch_contractCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.